"""Sphinx configuration file."""
import os
import sys

import django
from pkg_resources import get_distribution

os.environ.setdefault("DJANGO_SETTINGS_MODULE", "tests.testapp.settings")
sys.path.insert(0, os.path.abspath('..'))
django.setup()

project = "Django Mail Auth"
copyright = "2019, Johannes Hoppe"
release = get_distribution('django-mail-auth').version
version = '.'.join(release.split('.')[:2])

master_doc = 'index'

extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.napoleon',
    'sphinx.ext.intersphinx',
    'sphinx.ext.doctest',
]

intersphinx_mapping = {
    'python': ('https://docs.python.org/3', None),
    'django': ('https://docs.djangoproject.com/en/stable/',
               'https://docs.djangoproject.com/en/stable/_objects/'),
}


autodoc_default_options = {
    'show-inheritance': True,
}



from django.contrib import admin
from django.contrib.auth.models import Group, Permission

from . import models


@admin.register(models.EmailUser)
class EmailUserAdmin(admin.ModelAdmin):
    app_label = 'asdf'
    list_display = ('email', 'first_name', 'last_name', 'is_staff')
    list_filter = ('is_staff', 'is_superuser', 'is_active', 'groups')
    search_fields = ('first_name', 'last_name', 'email')
    ordering = ('email',)
    filter_horizontal = ('groups', 'user_permissions',)

    fieldsets = (
        (None, {
            'fields': (('email', 'is_active'), ('first_name', 'last_name'))
        }),
        (Group._meta.verbose_name_plural, {
            'fields': ('groups',),
        }),
        (Permission._meta.verbose_name_plural, {
            'classes': ('collapse',),
            'fields': (('is_staff', 'is_superuser'), 'user_permissions'),
        }),
    )



from django.contrib import messages
from django.http import response
from django.utils.translation import gettext_lazy as _
from wagtail.admin.views.account import LoginView as WagtailLoginView

from mailauth.forms import EmailLoginForm

__all__ = ('LoginView',)


class LoginView(WagtailLoginView):
    """Authentication view for Wagtail admin."""

    def get_form_class(self):
        return EmailLoginForm

    def form_valid(self, form):
        form.save()
        messages.add_message(
            self.request,
            messages.SUCCESS,
            _('We sent you an email with instructions to log into your account.'),
        )
        return response.HttpResponseRedirect(self.get_success_url())
